#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-bword
version:              0.1.0.1
visibility:           public
id:                   data-bword-0.1.0.1-AULvfz1x2yEHefd7vgdlIA
key:                  data-bword-0.1.0.1-AULvfz1x2yEHefd7vgdlIA
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-bword
synopsis:             Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.

category:             Data
abi:                  319ed69d4c017232c75f9d076829af21
exposed:              True
exposed-modules:      Data.BinaryWord
import-dirs:          /usr/lib/ghc-8.10.5/site-local/data-bword-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/data-bword-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/data-bword-0.1.0.1
hs-libraries:         HSdata-bword-0.1.0.1-AULvfz1x2yEHefd7vgdlIA
depends:              base-4.14.2.0 ghc-prim-0.6.1
haddock-interfaces:   /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html:         /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

